@@ -32,13 +32,13 @@ class ObservingBlock(object):
         """
         Parameters
         ----------
-        target: `~astroplan.FixedTarget'
+        target : `~astroplan.FixedTarget`
             Target to observe
 
         duration : `~astropy.units.Quantity`
             exposure time
 
-        priority: integer or float
+        priority : integer or float
             priority of this object in the target list. 1 is highest priority,
             no maximum
 
@@ -217,15 +217,14 @@ class TransitionBlock(object):
 
 class Schedule(object):
     """
-    An object that represents a schedule, consisting ofa list of
-    `~astroplan.scheduling.Slot` objects
+    An object that represents a schedule, consisting of a list of `~astroplan.scheduling.Slot` objects.
     """
     # as currently written, there should be no consecutive unoccupied slots
     # this should change to allow for more flexibility (e.g. dark slots, grey slots)
 
     def __init__(self, start_time, end_time, constraints=None):
         """
-        Parameters:
+        Parameters
         -----------
         start_time : `~astropy.time.Time`
             The starting time of the schedule; the start of your
@@ -233,7 +232,7 @@ class Schedule(object):
         end_time : `~astropy.time.Time`
            The ending time of the schedule; the end of your
            observing window
-        constraints : sequence of `Constraint`s
+        constraints : sequence of `~astroplan.constraints.Constraint` s
            these are constraints that apply to the entire schedule
         """
         self.start_time = start_time
@@ -360,7 +359,7 @@ class Slot(object):
 
     def __init__(self, start_time, end_time):
         """
-        Parameters:
+        Parameters
         -----------
         start_time : `~astropy.time.Time`
             The starting time of the slot
@@ -477,7 +476,8 @@ class Scheduler(object):
         ----------
         blocks : list of `~astroplan.scheduling.ObservingBlock` objects
             Can be modified as it is already copied by ``__call__``
-         Returns
+
+        Returns
         -------
         schedule : `~astroplan.scheduling.Schedule`
             A schedule objects which consists of `~astroplan.scheduling.Slot`
@@ -526,7 +526,7 @@ class SequentialScheduler(Scheduler):
             pre_filled = filled_times.reshape((2, 2))
         else:
             filled_times = Time(pre_filled.flatten())
-            pre_filled = filled_times.reshape((len(filled_times)/2, 2))
+            pre_filled = filled_times.reshape((int(len(filled_times)/2), 2))
         for b in blocks:
             if b.constraints is None:
                 b._all_constraints = self.constraints
@@ -654,8 +654,9 @@ class PriorityScheduler(Scheduler):
                                block in self.schedule.scheduled_blocks])
         for start_end in pre_filled:
             filled = np.where((start_end[0] < times) & (times < start_end[1]))
-            is_open_time[filled[0]] = False
-            is_open_time[min(filled[0]) - 1] = False
+            if len(filled[0]) > 0:
+                is_open_time[filled[0]] = False
+                is_open_time[min(filled[0]) - 1] = False
         # generate the score arrays for all of the blocks
         scorer = Scorer(blocks, self.observer, self.schedule, global_constraints=self.constraints)
         score_array = scorer.create_score_array(time_resolution)
@@ -727,34 +728,40 @@ class PriorityScheduler(Scheduler):
                         # make a transition object after the previous ObservingBlock
                         tb = self.transitioner(self.schedule.slots[slot_index - 1].block, b,
                                                self.schedule.slots[slot_index - 1].end, self.observer)
-                        times_indices = np.int(np.ceil(float(tb.duration / time_resolution)))
-                        tb.duration = times_indices * time_resolution
-                        start_idx = self.schedule.slots[slot_index - 1].block.end_idx
-                        end_idx = times_indices + start_idx
-                        # this may make some OBs get sub-optimal scheduling, but it closes gaps
-                        # TODO: determine a reasonable range inside which it gets shifted
-                        if (new_start_time - tb.start_time < tb.duration or
-                                abs(new_start_time - tb.end_time) < self.gap_time):
-                            new_start_time = tb.end_time
-                            start_time_idx = end_idx
-                        self.schedule.insert_slot(tb.start_time, tb)
-                        is_open_time[start_idx: end_idx] = False
-                        slot_index += 1
+                        # we may have a None type transition, which indicates two identical
+                        # ObservingBlocks, so no need to insert TransitionBlock
+                        if tb is not None:
+                            times_indices = np.int(np.ceil(float(tb.duration / time_resolution)))
+                            tb.duration = times_indices * time_resolution
+                            start_idx = self.schedule.slots[slot_index - 1].block.end_idx
+                            end_idx = times_indices + start_idx
+                            # this may make some OBs get sub-optimal scheduling, but it closes gaps
+                            # TODO: determine a reasonable range inside which it gets shifted
+                            if (new_start_time - tb.start_time < tb.duration or
+                                    abs(new_start_time - tb.end_time) < self.gap_time):
+                                new_start_time = tb.end_time
+                                start_time_idx = end_idx
+                            self.schedule.insert_slot(tb.start_time, tb)
+                            is_open_time[start_idx: end_idx] = False
+                            slot_index += 1
                         # Remove times from the master time list (copied in later code blocks)
                     elif isinstance(self.schedule.slots[slot_index - 1].block, TransitionBlock):
                         # change the existing TransitionBlock to what it needs to be now
                         tb = self.transitioner(self.schedule.slots[slot_index - 2].block, b,
                                                self.schedule.slots[slot_index - 2].end, self.observer)
-                        times_indices = np.int(np.ceil(float(tb.duration / time_resolution)))
-                        tb.duration = times_indices * time_resolution
-                        start_idx = self.schedule.slots[slot_index - 2].block.end_idx
-                        end_idx = times_indices + start_idx
-                        self.schedule.change_slot_block(slot_index - 1, new_block=tb)
-                        if (new_start_time - tb.start_time < tb.duration or
-                                abs(new_start_time - tb.end_time) < self.gap_time):
-                            new_start_time = tb.end_time
-                            start_time_idx = end_idx
-                        is_open_time[start_idx: end_idx] = False
+                        # we may have a None type transition, which indicates two identical
+                        # ObservingBlocks, so no need to insert TransitionBlock
+                        if tb is not None:
+                            times_indices = np.int(np.ceil(float(tb.duration / time_resolution)))
+                            tb.duration = times_indices * time_resolution
+                            start_idx = self.schedule.slots[slot_index - 2].block.end_idx
+                            end_idx = times_indices + start_idx
+                            self.schedule.change_slot_block(slot_index - 1, new_block=tb)
+                            if (new_start_time - tb.start_time < tb.duration or
+                                    abs(new_start_time - tb.end_time) < self.gap_time):
+                                new_start_time = tb.end_time
+                                start_time_idx = end_idx
+                            is_open_time[start_idx: end_idx] = False
                 end_time_idx = duration_indices + start_time_idx
 
                 if slots_after:
@@ -762,12 +769,15 @@ class PriorityScheduler(Scheduler):
                         # make a transition object after the new ObservingBlock
                         tb = self.transitioner(b, self.schedule.slots[slot_index + 1].block,
                                                new_start_time + b.duration, self.observer)
-                        times_indices = np.int(np.ceil(float(tb.duration / time_resolution)))
-                        tb.duration = times_indices * time_resolution
-                        self.schedule.insert_slot(tb.start_time, tb)
-                        start_idx = end_time_idx
-                        end_idx = start_idx + times_indices
-                        is_open_time[start_idx: end_idx] = False
+                        # we may have a None type transition, which indicates two identical
+                        # ObservingBlocks, so no need to insert TransitionBlock
+                        if tb is not None:
+                            times_indices = np.int(np.ceil(float(tb.duration / time_resolution)))
+                            tb.duration = times_indices * time_resolution
+                            self.schedule.insert_slot(tb.start_time, tb)
+                            start_idx = end_time_idx
+                            end_idx = start_idx + times_indices
+                            is_open_time[start_idx: end_idx] = False
 
                 # now assign the block itself times and add it to the schedule
                 b.constraints = b._all_constraints
@@ -835,20 +845,21 @@ class Transitioner(object):
             # to observer
             from .constraints import _get_altaz
             from astropy.time import Time
+            if oldblock.target != newblock.target:
+                aaz = _get_altaz(Time([start_time]), observer,
+                                 [oldblock.target, newblock.target])['altaz']
+                # TODO: make this [0] unnecessary by fixing _get_altaz to behave well in scalar-time case
+                sep = aaz[0].separation(aaz[1])[0]
+                if sep/self.slew_rate > 1 * u.second:
+                    components['slew_time'] = sep / self.slew_rate
 
-            aaz = _get_altaz(Time([start_time]), observer,
-                             [oldblock.target, newblock.target])['altaz']
-            # TODO: make this [0] unnecessary by fixing _get_altaz to behave well in scalar-time case
-            sep = aaz[0].separation(aaz[1])[0]
-
-            components['slew_time'] = sep / self.slew_rate
         if self.instrument_reconfig_times is not None:
             components.update(self.compute_instrument_transitions(oldblock, newblock))
 
         if components:
             return TransitionBlock(components, start_time)
         else:
-            return TransitionBlock.from_duration(0*u.second)
+            return None
 
     def compute_instrument_transitions(self, oldblock, newblock):
         components = {}
